/*	@(#)prestoctl.x 2.2 90/07/06 Copyright (c) 1990, Legato Systems, Inc.	*/

/*
 * Copyright (c) 1990, Legato Systems Incorporated.
 *
 * All rights reserved.
 */

/*
 * RPC protocol definition for controlling and monitoring presto devices.
 */

enum battery {
	BAT_GOOD 	= 0,	/* battery is well charged */
	BAT_LOW		= 1,	/* battery has a low charge */
	BAT_DISABLED	= 2,	/* battery is currently disabled */
	BAT_IGNORE	= 3	/* this board doesn't have this battery */
};

const MAX_BATTERIES	= 8;	/* more then we'll ever need */

enum prstates { 		/* internal states of the presto board */
	PRDOWN 	= 0,
	PRUP	= 1,
	PRERROR	= 2
};

/*
 * The io struct is used to keep statistics when presto is enabled.
 * There are separate statistics kept in the presto_status structure
 * for reads and writes.
 *
 * 		total = hitclean + hitdirty + pass + alloc
 */

struct io {
	u_int	total;		/* total number of reads or writes */
	u_int	hitclean;	/* num of reqs found in cache as ``clean'' */
	u_int	hitdirty;	/* num of reqs found in cache as ``dirty'' */
	u_int	pass;		/* num of reqs passed thru to real device */
	u_int	alloc;		/* num of reqs that allocated buf space */
};

struct presto_status {
	prstates pr_state;	/* if not PRUP, pass all rw commands thru */
	u_int	pr_battcnt;
	battery	pr_batt[MAX_BATTERIES];	/* array of battery status flags */
	u_int	pr_maxsize;	/* total memory size in bytes available */
	u_int	pr_cursize;	/* current presto memory size */
	u_int	pr_ndirty;	/* current number of dirty presto buffers */
	u_int	pr_nclean;	/* current number of clean presto buffers */
	u_int	pr_ninval;	/* current number of invalid presto buffers */
	u_int	pr_nactive;	/* current number of active presto buffers */
	/* the io stats are zeroed each time presto is reenabled */
	io 	pr_rdstats;	/* presto read statistics */
	io 	pr_wrstats;	/* presto write statistics */
	u_int	pr_seconds;	/* # of seconds of stats recorded */
};

union	presto_modstat switch (bool ps_status) {
	case FALSE:	/* operation failed; the string says why */
		string	ps_errmsg<>;
	case TRUE:	/* operation suceeded; new state returned */
		struct presto_status ps_new;
};

struct presto_fs_status {
	bool pfs_prestoized;	/* fs is prestoized */
	prstates pfs_state;	/* state of presto board this fs is on */
	bool pfs_enabled;	/* presto is enabled on this fs */
	bool pfs_bounceio;	/* presto is set for bounceio on this fs */
	bool pfs_unused;
};

union	presto_get_fs_status switch (bool succeeded) {
	case FALSE:	/* operation failed; the string says why */
		string			errmsg<>;
	case TRUE:	/* operation suceeded; presto status of fs returned */
		presto_fs_status	status;
};

program PRESTOCTLPROG {
	version PRESTOCTLVERS{

		presto_modstat
		PRESTOCTL_GETSTATE (void) = 1;

		/*
		 * a change implies toggling the board DOWN, then UP.
		 */
		presto_modstat
		PRESTOCTL_SETBYTES (unsigned) = 2;

		/*
		 * turning ON the board zeros the counters.
		 */
		presto_modstat
		PRESTOCTL_TOGGLE (bool) = 3;  /* TRUE is ON, FALSE is OFF */

		/*
		 * What is the status of the named filesystem ?
		 */
		presto_get_fs_status
		PRESTOCTL_GET_FS_STATUS (string) = 4;

	} = 3;
} = 390100;
